@@ -140,6 +140,18 @@ has sku => (
     required => 1,
 );
 
+=head2 canonical_sku
+
+If this product is a variant of a "parent" product then C<canonical_sku>
+is the sku of the parent product.
+
+=cut
+
+has canonical_sku => (
+    is      => 'ro',
+    default => undef,
+);
+
 =head2 subtotal
 
 Subtotal calculated as L</price> * L</quantity>. Lazy set via builder.
@@ -184,10 +196,22 @@ Product uri
 =cut
 
 has uri => (
-    is  => 'rw',
+    is  => 'ro',
     isa => VarChar [255],
 );
 
+=head2 weight
+
+Weight of quantity 1 of this product.
+
+=cut
+
+has weight => (
+    is     => 'ro',
+    isa    => AnyOf [ Undef, Num ],
+    writer => 'set_weight',
+);
+
 =head2 extra
 
 Hash reference of extra things the cart product might want to store such as:
@@ -282,6 +306,27 @@ Clears L</total>.
 
 predicate on L</total>.
 
+
+=item * is_variant
+
+Returns 1 if L</canonical_sku> is defined else 0.
+
+=cut
+
+sub is_variant {
+    return defined shift->canonical_sku ? 1 : 0;
+}
+
+=item * is_canonical
+
+Returns 0 if L</canonical_sku> is defined else 1.
+
+=cut
+
+sub is_canonical {
+    return defined shift->canonical_sku ? 0 : 1;
+}
+
 =back
 
 =cut
